import { fileURLToPath } from 'url';
import { defineConfig } from 'vitepress';
import footnote from 'markdown-it-footnote';

export default defineConfig({
  title: 'HPG Romein',
  lang: 'nl',
  assetsDir: 'immutable',

  themeConfig: {
    sidebar: [
      { text: '2023',
        collapsed: false,
        items: [
          { text: 'Startreflectie', link: '/2023/startreflectie/' },
          { text: 'Projecten', items: [
            { text: '1. Betonplaat', link: '/2023/betonplaat/' },
            { text: '2. Boek', link: '/2023/boek/' },
            { text: '3a. Top-30 tips', link: '/2023/top30/' },
          ] },
          { text: 'Geleerd', link: '/2023/geleerd/' },
          { text: 'Leerdoelen', link: '/2023/leerdoelen/' },
          { text: 'Toekomst', link: '/2023/toekomst/' },
          { text: 'Hoe verder?', link: '/2023/hoeverder/' },
          { text: 'Een uitstapje', link: '/2023/bredagelijk/' },
        ],
      },
      { text: '2024',
        collapsed: false,
        items: [
          { text: 'Nieuwe start', link: '/2024/nieuwestart/' },
          { text: 'Inschrijving', link: '/2024/inschrijving/' },
          { text: 'Eerste overeenkomst', link: '/2024/overeenkomst/' },
          { text: 'Verzekeringen verkopen', link: '/2024/pluzeker/' },
          { text: 'Kwikstaart', link: '/2024/wagtail/' },
          { text: 'Malmö', link: '/2024/malmo/' },
        ],
      },
    ],

    darkModeSwitchLabel: 'Donker thema',
    lightModeSwitchTitle: 'Donker thema',
    darkModeSwitchTitle: 'Licht thema',
    returnToTopLabel: 'Terug naar boven',

    docFooter: {
      prev: 'Vorige',
      next: 'Volgende',
    },

    outline: {
      label: 'Pagina-inhoud',
    },

    copyright: `© 2022-${new Date().getFullYear()} Romein van Buren.`,
  },

  markdown: {
    config: md => {
      md.use(footnote);
    },
  },

  vite: {
    resolve: {
      alias: [
        { find: /^.*\/VPDocFooter\.vue$/,
          replacement: fileURLToPath(new URL('./theme/VPDocFooter.vue', import.meta.url)),
        },
      ],
    },
  },
});
